==> haskell-bencode-0.6.1.1-200-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bencode
version:              0.6.1.1
visibility:           public
id:                   bencode-0.6.1.1-GZPDGNnITUV6j0ihXCYeu
key:                  bencode-0.6.1.1-GZPDGNnITUV6j0ihXCYeu
license:              BSD-3-Clause
copyright:
    (c) 2005-2009, David Himmelstrup,
    (c) 2006 Lemmih <lemmih@gmail.com>,
    (c) 2005 Jesper Louis Andersen <jlouis@mongers.org>

maintainer:           Peter Simons <simons@cryp.to>
author:
    Lemmih <lemmih@gmail.com>,
    Jesper Louis Andersen <jlouis@mongers.org>,
    Christopher Reichert <creichert07@gmail.com>

synopsis:             Parsers and printers for bencoded data.
description:
    Parsers and printers for bencoded data. Bencode (pronounced like B
    encode) is the encoding used by the peer-to-peer file sharing system
    BitTorrent for storing and transmitting loosely structured data.

category:             Text
abi:                  8becc5c8fdabfbc9bc7a61363161d8c7
exposed:              True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
    Data.BEncode.Reader

import-dirs:          /usr/lib/ghc-9.2.8/site-local/bencode-0.6.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bencode-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bencode
hs-libraries:         HSbencode-0.6.1.1-GZPDGNnITUV6j0ihXCYeu
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    parsec-3.1.15.0 transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:   /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html:         /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bencode-0.6.1.1-202-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bencode
version:              0.6.1.1
visibility:           public
id:                   bencode-0.6.1.1-A7AeOnAyjtRHztzG5Ie1b
key:                  bencode-0.6.1.1-A7AeOnAyjtRHztzG5Ie1b
license:              BSD-3-Clause
copyright:
    (c) 2005-2009, David Himmelstrup,
    (c) 2006 Lemmih <lemmih@gmail.com>,
    (c) 2005 Jesper Louis Andersen <jlouis@mongers.org>

maintainer:           Peter Simons <simons@cryp.to>
author:
    Lemmih <lemmih@gmail.com>,
    Jesper Louis Andersen <jlouis@mongers.org>,
    Christopher Reichert <creichert07@gmail.com>

synopsis:             Parsers and printers for bencoded data.
description:
    Parsers and printers for bencoded data. Bencode (pronounced like B
    encode) is the encoding used by the peer-to-peer file sharing system
    BitTorrent for storing and transmitting loosely structured data.

category:             Text
abi:                  bbec5a2ec8aa993483954f3673eb7395
exposed:              True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
    Data.BEncode.Reader

import-dirs:          /usr/lib/ghc-9.2.8/site-local/bencode-0.6.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bencode-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bencode
hs-libraries:         HSbencode-0.6.1.1-A7AeOnAyjtRHztzG5Ie1b
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    parsec-3.1.15.0 transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:   /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html:         /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
